@@ -1,5 +1,6 @@
-use pretend::{pretend, request, Pretend, Result, Serialize, Url};
-use pretend_reqwest::Client as RClient;
+use pretend::{pretend, request, Pretend, Result, Url};
+use pretend_reqwest::Client;
+use serde::Serialize;
 
 // This example show how to pass URL queries to https://httpbin.org
 
@@ -20,7 +21,7 @@ trait HttpBin {
 
 fn create_pretend() -> impl HttpBin {
     let url = Url::parse("https://httpbin.org").unwrap();
-    Pretend::for_client(RClient::default()).with_url(url)
+    Pretend::for_client(Client::default()).with_url(url)
 }
 
 #[tokio::main]
