@@ -10,15 +10,14 @@ use pretend::{HeaderMap, Response, Result, Url};
 use pretend_awc::Client as AClient;
 use pretend_isahc::Client as IClient;
 use pretend_reqwest::{BlockingClient as RBlockingClient, Client as RClient};
+use pretend_ureq::ureq::AgentBuilder;
+use pretend_ureq::Client as UClient;
 
 fn create_testable<C>(client: C) -> Box<dyn TestableClient>
 where
     C: Client + 'static,
 {
-    Box::new(TokioTestableClient::new(
-        Box::new(client),
-        runtimes::create_runtime(),
-    ))
+    Box::new(TokioTestableClient::new(client, runtimes::create_runtime()))
 }
 
 fn create_testable_local<C>(client: C) -> Box<dyn TestableClient>
@@ -26,7 +25,7 @@ where
     C: LocalClient + 'static,
 {
     Box::new(TokioTestableLocalClient::new(
-        Box::new(client),
+        client,
         runtimes::create_runtime(),
     ))
 }
@@ -85,7 +84,10 @@ fn test_local_clients(url: Url) {
 }
 
 fn test_blocking_clients(url: Url) {
-    let clients: Vec<Box<dyn TestableClient>> = vec![Box::new(RBlockingClient::default())];
+    let clients: Vec<Box<dyn TestableClient>> = vec![
+        Box::new(RBlockingClient::default()),
+        Box::new(UClient::new(AgentBuilder::new().build())),
+    ];
     let tester = ClientsTester::new(url, clients);
     tester.test();
 }
